# Copyright (C) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See LICENSE in project root for information.


import sys
if sys.version >= '3':
    basestring = str

from pyspark.ml.param.shared import *
from pyspark import keyword_only
from pyspark.ml.util import JavaMLReadable, JavaMLWritable
from pyspark.ml.wrapper import JavaTransformer, JavaEstimator, JavaModel
from pyspark.ml.common import inherit_doc
from mmlspark.Utils import *
from mmlspark.TypeConversionUtils import generateTypeConverter, complexTypeConverter

@inherit_doc
class SimpleHTTPTransformer(ComplexParamsMixin, JavaMLReadable, JavaMLWritable, JavaTransformer):
    """


    Args:

        concurrency (int): max number of concurrent calls (default: 1)
        concurrentTimeout (double): max number seconds to wait on futures if concurrency >= 1 (default: 100.0)
        flattenOutputBatches (bool): whether to flatten the output batches (default: false)
        handlingStrategy (str): Which strategy to use when handling requests (default: advanced)
        inputCol (str): The name of the input column
        inputParser (object): format to parse the column to (default: JSONInputParser_47523377636f)
        maxBatchSize (int): The max size of the buffer
        outputCol (str): The name of the output column
        outputParser (object): format to parse the column to
    """

    @keyword_only
    def __init__(self, concurrency=1, concurrentTimeout=100.0, flattenOutputBatches=False, handlingStrategy="advanced", inputCol=None, inputParser=None, maxBatchSize=None, outputCol=None, outputParser=None):
        super(SimpleHTTPTransformer, self).__init__()
        self._java_obj = self._new_java_obj("com.microsoft.ml.spark.SimpleHTTPTransformer")
        self._cache = {}
        self.concurrency = Param(self, "concurrency", "concurrency: max number of concurrent calls (default: 1)")
        self._setDefault(concurrency=1)
        self.concurrentTimeout = Param(self, "concurrentTimeout", "concurrentTimeout: max number seconds to wait on futures if concurrency >= 1 (default: 100.0)")
        self._setDefault(concurrentTimeout=100.0)
        self.flattenOutputBatches = Param(self, "flattenOutputBatches", "flattenOutputBatches: whether to flatten the output batches (default: false)")
        self._setDefault(flattenOutputBatches=False)
        self.handlingStrategy = Param(self, "handlingStrategy", "handlingStrategy: Which strategy to use when handling requests (default: advanced)")
        self._setDefault(handlingStrategy="advanced")
        self.inputCol = Param(self, "inputCol", "inputCol: The name of the input column")
        self.inputParser = Param(self, "inputParser", "inputParser: format to parse the column to (default: JSONInputParser_47523377636f)", generateTypeConverter("inputParser", self._cache, complexTypeConverter))
        self.maxBatchSize = Param(self, "maxBatchSize", "maxBatchSize: The max size of the buffer")
        self.outputCol = Param(self, "outputCol", "outputCol: The name of the output column")
        self.outputParser = Param(self, "outputParser", "outputParser: format to parse the column to", generateTypeConverter("outputParser", self._cache, complexTypeConverter))
        if hasattr(self, "_input_kwargs"):
            kwargs = self._input_kwargs
        else:
            kwargs = self.__init__._input_kwargs
        self.setParams(**kwargs)

    @keyword_only
    def setParams(self, concurrency=1, concurrentTimeout=100.0, flattenOutputBatches=False, handlingStrategy="advanced", inputCol=None, inputParser=None, maxBatchSize=None, outputCol=None, outputParser=None):
        """
        Set the (keyword only) parameters

        Args:

            concurrency (int): max number of concurrent calls (default: 1)
            concurrentTimeout (double): max number seconds to wait on futures if concurrency >= 1 (default: 100.0)
            flattenOutputBatches (bool): whether to flatten the output batches (default: false)
            handlingStrategy (str): Which strategy to use when handling requests (default: advanced)
            inputCol (str): The name of the input column
            inputParser (object): format to parse the column to (default: JSONInputParser_47523377636f)
            maxBatchSize (int): The max size of the buffer
            outputCol (str): The name of the output column
            outputParser (object): format to parse the column to
        """
        if hasattr(self, "_input_kwargs"):
            kwargs = self._input_kwargs
        else:
            kwargs = self.__init__._input_kwargs
        return self._set(**kwargs)

    def setConcurrency(self, value):
        """

        Args:

            concurrency (int): max number of concurrent calls (default: 1)

        """
        self._set(concurrency=value)
        return self


    def getConcurrency(self):
        """

        Returns:

            int: max number of concurrent calls (default: 1)
        """
        return self.getOrDefault(self.concurrency)


    def setConcurrentTimeout(self, value):
        """

        Args:

            concurrentTimeout (double): max number seconds to wait on futures if concurrency >= 1 (default: 100.0)

        """
        self._set(concurrentTimeout=value)
        return self


    def getConcurrentTimeout(self):
        """

        Returns:

            double: max number seconds to wait on futures if concurrency >= 1 (default: 100.0)
        """
        return self.getOrDefault(self.concurrentTimeout)


    def setFlattenOutputBatches(self, value):
        """

        Args:

            flattenOutputBatches (bool): whether to flatten the output batches (default: false)

        """
        self._set(flattenOutputBatches=value)
        return self


    def getFlattenOutputBatches(self):
        """

        Returns:

            bool: whether to flatten the output batches (default: false)
        """
        return self.getOrDefault(self.flattenOutputBatches)


    def setHandlingStrategy(self, value):
        """

        Args:

            handlingStrategy (str): Which strategy to use when handling requests (default: advanced)

        """
        self._set(handlingStrategy=value)
        return self


    def getHandlingStrategy(self):
        """

        Returns:

            str: Which strategy to use when handling requests (default: advanced)
        """
        return self.getOrDefault(self.handlingStrategy)


    def setInputCol(self, value):
        """

        Args:

            inputCol (str): The name of the input column

        """
        self._set(inputCol=value)
        return self


    def getInputCol(self):
        """

        Returns:

            str: The name of the input column
        """
        return self.getOrDefault(self.inputCol)


    def setInputParser(self, value):
        """

        Args:

            inputParser (object): format to parse the column to (default: JSONInputParser_47523377636f)

        """
        self._set(inputParser=value)
        return self


    def getInputParser(self):
        """

        Returns:

            object: format to parse the column to (default: JSONInputParser_47523377636f)
        """
        return self._cache.get("inputParser", None)


    def setMaxBatchSize(self, value):
        """

        Args:

            maxBatchSize (int): The max size of the buffer

        """
        self._set(maxBatchSize=value)
        return self


    def getMaxBatchSize(self):
        """

        Returns:

            int: The max size of the buffer
        """
        return self.getOrDefault(self.maxBatchSize)


    def setOutputCol(self, value):
        """

        Args:

            outputCol (str): The name of the output column

        """
        self._set(outputCol=value)
        return self


    def getOutputCol(self):
        """

        Returns:

            str: The name of the output column
        """
        return self.getOrDefault(self.outputCol)


    def setOutputParser(self, value):
        """

        Args:

            outputParser (object): format to parse the column to

        """
        self._set(outputParser=value)
        return self


    def getOutputParser(self):
        """

        Returns:

            object: format to parse the column to
        """
        return self._cache.get("outputParser", None)



    @classmethod
    def read(cls):
        """ Returns an MLReader instance for this class. """
        return JavaMMLReader(cls)

    @staticmethod
    def getJavaPackage():
        """ Returns package name String. """
        return "com.microsoft.ml.spark.SimpleHTTPTransformer"

    @staticmethod
    def _from_java(java_stage):
        module_name=SimpleHTTPTransformer.__module__
        module_name=module_name.rsplit(".", 1)[0] + ".SimpleHTTPTransformer"
        return from_java(java_stage, module_name)
